diff -ru moin-1.2.2/MoinMoin/PageEditor.py moin-1.2.2jm/MoinMoin/PageEditor.py
--- moin-1.2.2/MoinMoin/PageEditor.py	2004-06-05 16:58:36.000000000 -0700
+++ moin-1.2.2jm/MoinMoin/PageEditor.py	2004-06-07 15:44:05.000000000 -0700
@@ -539,6 +539,26 @@
 
         return wiki_is_smarter_than_its_users + _('Nobody subscribed to this page, no mail sent.')
 
+    def _notifyCommitMail(self, comment):
+        """
+        Send email to a single address with the update notification of this page.
+
+        @param comment: editor's comment given when saving the page
+        @rtype: string
+        @return: message, indicating success or errors.
+        """
+        _ = self._
+
+        # get a list of old revisions, and append a diff
+        oldversions = wikiutil.getBackupList(config.backup_dir, self.page_name)
+        addr = config.mail_commits_address
+        lang = config.mail_commits_lang
+        mailok, status = self._sendNotification(comment, [ addr ],
+                                lang, oldversions)
+
+        return _('<br>Sent commit message to %(recipient)s.') % {
+                'recipient': addr}
+
 
     def _user_variable(self):
         """
@@ -788,6 +808,9 @@
             if config.mail_smarthost and kw.get('notify', 0):
                 msg = msg + self._notifySubscribers(kw.get('comment', ''))
 
+            if config.mail_smarthost and config.mail_commits_address:
+                msg = msg + self._notifyCommitMail(kw.get('comment', ''))
+
         # remove lock (forcibly if we were allowed to break it by the UI)
         # !!! this is a little fishy, since the lock owner might not notice
         # we broke his lock ==> but datestamp checking during preview will
diff -ru moin-1.2.2/MoinMoin/config.py moin-1.2.2jm/MoinMoin/config.py
--- moin-1.2.2/MoinMoin/config.py	2004-06-05 16:58:23.000000000 -0700
+++ moin-1.2.2jm/MoinMoin/config.py	2004-06-07 15:42:55.000000000 -0700
@@ -85,6 +86,8 @@
     'mail_login': None, # or "user pwd" if you need to use SMTP AUTH
     'mail_smarthost': None,
     'mail_from': None,
+    'mail_commits_address': None,
+    'mail_commits_lang': 'en',
     'max_macro_size': 50,
     'navi_bar': [
         'FrontPage',
diff -ru moin-1.2.2/wiki/cgi-bin/moin_config.py moin-1.2.2jm/wiki/cgi-bin/moin_config.py
--- moin-1.2.2/wiki/cgi-bin/moin_config.py	2004-06-05 16:58:16.000000000 -0700
+++ moin-1.2.2jm/wiki/cgi-bin/moin_config.py	2004-06-07 15:42:11.000000000 -0700
@@ -27,6 +27,12 @@
 url_prefix = '/wiki'
 logo_url = url_prefix + '/classic/img/moinmoin.png'
 
+# Send commit messages?
+mail_commits_address = 'jm@jmason.org'
+mail_commits_lang = 'en'
+mail_smarthost = 'localhost'
+
+
 # encoding and WikiName char sets
 # (change only for outside America or Western Europe)
 charset = 'iso-8859-1'
